@@ -88,6 +88,17 @@ L<ASP4::API>.
 TransHandlers are a handy way of jumping into "normal" mod_perl handler mode without
 losing access to your web application's config.
 
+=head1 BUGS
+
+It's possible that some bugs have found their way into this release.
+
+Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=ASP4> to submit bug reports.
+
+=head1 HOMEPAGE
+
+Please visit the ASP4 homepage at L<http://0x31337.org/code/> to see examples
+of ASP4 in action.
+
 =cut
 
 
